
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: C_Container, NUM_BAG_SLOTS, tonumber

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Automation Sell")

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:RegisterEvent("MERCHANT_CLOSED")
	self:RegisterEvent("MERCHANT_SHOW")
end

function M:IterateContainerItems()
	return coroutine.wrap(function()
		for container = 0, NUM_BAG_SLOTS do
			for slot = 1, C_Container.GetContainerNumSlots(container) do
				local itemInfo = C_Container.GetContainerItemInfo(container, slot)
				
				if itemInfo then
					coroutine.yield(container, slot, itemInfo)
				end
			end
		end
	end)
end

function M:SellAllJunkItems()
	for container, slot, itemInfo in self:IterateContainerItems() do
		if self.isMerchantFrameShown and itemInfo.quality == Enum.ItemQuality.Poor and not itemInfo.noValue and not self:IsIgnored(itemInfo.itemID) then
			C_Container.UseContainerItem(container, slot)
		end
	end
end

-------------------------------------------------------------------------------
-- Ignore List
-------------------------------------------------------------------------------

function M:GetIgnoreList()
	return self.config.blacklist
end

function M:Ignore(value)
	for itemLink, itemID in value:gmatch("(|c[^|]+|Hitem:(%d+):[^|]+|h%[.-%]|h|r)") do
		self.config.blacklist[tonumber(itemID)] = itemLink
	end
end

function M:IsIgnored(itemID)
	return self.config.blacklist[itemID] ~= nil
end

function M:Unignore(itemID)
	self.config.blacklist[itemID] = nil
end

-------------------------------------------------------------------------------
-- Events
-------------------------------------------------------------------------------

function M:MERCHANT_CLOSED()
	self.isMerchantFrameShown = false
end

function M:MERCHANT_SHOW()
	self.isMerchantFrameShown = true

	if C_MerchantFrame.IsSellAllJunkEnabled() and C_MerchantFrame.GetNumJunkItems() > 0 then
		self:SellAllJunkItems()
	end
end
